#
# spec file for package xwd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xwd
Version:        1.0.9
Release:        1.5
Summary:        Utility to dump an image of an X window
License:        MIT
Group:          System/X11/Utilities
URL:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xkbfile)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Xwd is an X Window System window dumping utility. It allows X users to
store window images in a specially formatted dump file. This file can
then be read by various other X utilities for redisplay, printing,
editing, formatting, archiving, image processing, etc.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%doc ChangeLog COPYING README.md
%{_bindir}/xwd
%{_mandir}/man1/xwd.1%{?ext_man}

%changelog
* Sat Jun 10 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.9
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * gitlab CI: stop requiring Signed-off-by in commits
  * Remove unused macros
  * Handle -Wcomma warnings from clang
  * Remove unnecessary casts from malloc() and free() calls
  * Variable scope reduction as recommended by cppcheck
  * Delete commented-out local copy of list function prototypes
  * list.c: Stop building functions that are never called
  * Make -help & -version work without requiring an open display
* Mon Aug  2 2021 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.8
  * It fixes bugs you didn't even know were there and cleans up
    code you've never seen!
* Thu Apr  5 2018 sndirsch@suse.com
- Update to version 1.0.7
  * autogen.sh changes
  * configure: Drop AM_MAINTAINER_MODE
  * Print which option was in error along with usage message
  * Add -version option to print program version
  * Fix a vs an typo in the man page.
* Wed Aug 14 2013 zaitor@opensuse.org
- Update to version 1.0.6:
  + Strip trailing whitespace.
  + Fix some clang warnings about integer size/sign conversions.
  + Quiet gcc warnings about potentially uninitialized variables.
  + Remove unused bitmap_unit variable from ReadRegionsInList().
  + Rename new_list variable to not shadow new_list function.
  + Add printf attributes as suggested by
    gcc -Wmissing-format-attribute.
  + Fix gcc warnings about discarding const qualifiers.
  + Optionally enable existing code to call XkbStdBell from
    libxkbfile.
  + Move Pixel typedef from xwd.c to wsutils.h.
- Drop xwd-no-xt-dependency.patch: fixed upstream.
- Add pkgconfig(xkbfile) BuildRequires, new dependency.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.0.5:
  + Mark usage as _X_NORETURN.
  + Dead code removal.
  + Fix LP64 bug.
  + Replace local checks for gcc with _X_NORETURN from xproto
    7.0.17.
  + Rewrite parse_long to not fail -Wformat-nonliteral.
  + Man page fixes.
  + Build system fixes.
- Add pkgconfig(xproto) BuildRequires: New upstream dependency.
- Add xwd-no-xt-dependency.patch: Removes need for including
  <X11/Intrinsic.h> in multiVis.c just to get the Pixel typedef.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xwd from xorg-x11. Initial version: 1.0.4.
